@@ -28,7 +28,8 @@
 #include "libheif/heif.h"
 #include "test-config.h"
 #include <cstring>
-#include "catch.hpp"
+#include "catch_amalgamated.hpp"
+
 
 struct heif_context * get_context_for_test_file(std::string filename)
 {
@@ -174,3 +175,47 @@ std::string get_path_for_heifio_test_file(std::string filename)
 {
   return libheifio_tests_data_directory + "/" + filename;
 }
+
+
+heif_encoder* get_encoder_or_skip_test(heif_compression_format format)
+{
+  heif_encoder* encoder = nullptr;
+  heif_error err = heif_context_get_encoder_for_format(nullptr, format, &encoder);
+  if (err.code != heif_error_Ok) {
+    if (format == heif_compression_HEVC) {
+      SKIP("Encoder for HEVC not found, skipping test");
+    }
+    else if (format == heif_compression_AV1) {
+      SKIP("Encoder for AV1 not found, skipping test");
+    }
+    else {
+      SKIP("Encoder not found, skipping test");
+    }
+  }
+
+  return encoder;
+}
+
+
+fs::path get_tests_output_dir()
+{
+  if (const char* env_p = std::getenv("LIBHEIF_TEST_OUTPUT_DIR")) {
+    return fs::path(env_p);
+  }
+
+  static const fs::path output_dir = fs::current_path() / "libheif_test_output";
+
+  if (!fs::exists(output_dir)) {
+    fs::create_directories(output_dir);
+  }
+
+  return output_dir;
+}
+
+
+std::string get_tests_output_file_path(const char* filename)
+{
+  fs::path dir = get_tests_output_dir();
+  dir /= filename;
+  return dir.string();
+}
